################################################################
#                                                              #
#   What are psychological constructs? On the nature and       #
#       statistical modeling of emotions, intelligence,        #
#         personality traits and mental disorders.             #
#                                                              #
#                      Eiko I. Fried, 2017                     #
#                                                              #
################################################################

library("qgraph")          # Network estimation & inference
library("ggplot2")         # Visualization
library("bootnet")         # Network stability
library("dplyr")           # Simplify R code
library("tidyr")           # Simplify R code

### Figure 1

# A: Reflective cause model
M.1A <- matrix(0,11,11) 
M.1A[1,2] <-M.1A[1,3] <-M.1A[1,4] <-M.1A[1,5] <- M.1A[1,6] <- M.1A[1,7] <- M.1A[1,8] <- M.1A[1,9] <- M.1A[1,10] <- M.1A[1,11] <-.25
gr.1 <- list(1,2:11)
names1 <- c("PC",1:10)
L <- rbind(c(0,0),
           cbind(cos(0.5*pi - seq(0,2*pi,length=11)[-11]),
                 sin(0.5*pi - seq(0,2*pi,length=11)[-11])))

A <- qgraph(M.1A, border.width=c(6, rep(3, 10)), border.color='#555555', asize=12, vsize=c(18, rep(15,10)), 
            label.color="#555555", color="#EEEEEE", maximum=.45, labels=names1,
            layout = L)


# B: Formative model
M.1B <- matrix(0,11,11) 
M.1B[2,1] <- M.1B[3,1] <-M.1B[4,1] <-M.1B[5,1] <- M.1B[6,1] <- M.1B[7,1] <- M.1B[8,1] <- M.1B[9,1] <- M.1B[10,1] <- M.1B[11,1] <-.25

B <- qgraph(M.1B, border.width=c(6, rep(3, 10)), border.color='#555555', asize=11, vsize=c(18, rep(15,10)), 
            label.color="#555555", color="#EEEEEE", maximum=.45, labels=names1,
            layout = L)


# C: Network model
M.1C <- matrix(0,10,10) 
M.1C[1,3] <- M.1C[2,1] <- M.1C[2,4] <- M.1C[2,5] <- M.1C[2,3] <- M.1C[2,6] <- 
  M.1C[2,6] <- M.1C[5,2] <- M.1C[3,2] <- M.1C[3,6] <- M.1C[1,1] <- M.1C[5,5] <- 
  M.1C[8,8] <- M.1C[7,7] <- M.1C[9,9] <- M.1C[6,10]<- M.1C[6,8] <-
  M.1C[6,7] <- M.1C[10,9] <- .25

C <- qgraph(M.1C, border.width=3, border.color='#555555', asize=10, vsize=15, 
            label.color="#555555", color="#EEEEEE", maximum=.5)


### Plot
pdf("Figure1.pdf", width=15, height=5)
layout(t(1:3))
plot(A)
plot(B)
plot(C)
dev.off(); dev.off()
